package
Version:
v1.8.1
Opens a new window with list of versions in this module.
Published: Apr 14, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type H3ImpersonateData struct {
HTTP3 struct {
PerkText string `json:"perk_text"`
PerkHash string `json:"perk_hash"`
} `json:"http3"`
}
type PeetsApiCleanData struct {
Ja3 string `json:"ja3"`
Ja3Hash string `json:"ja3_hash"`
Akamai string `json:"akamai"`
AkamaiHash string `json:"akamai_hash"`
Peetprint string `json:"peetprint"`
PeetprintHash string `json:"peetprint_hash"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.